@@ -22,23 +22,22 @@ using namespace KAddressBook;
 
 K_PLUGIN_CLASS_WITH_JSON(KCMKaddressbookUserFeedBackConfig, "kaddressbook_config_userfeedback.json")
 
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
 KCMKaddressbookUserFeedBackConfig::KCMKaddressbookUserFeedBackConfig(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
     , mUserFeedbackWidget(new KUserFeedback::FeedbackConfigWidget(this))
+#else
+KCMKaddressbookUserFeedBackConfig::KCMKaddressbookUserFeedBackConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : KCModule(parent, data, args)
+    , mUserFeedbackWidget(new KUserFeedback::FeedbackConfigWidget(widget()))
+#endif
 {
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     auto lay = new QHBoxLayout(this);
+#else
+    auto lay = new QHBoxLayout(widget());
+#endif
     lay->setContentsMargins({});
-
-    auto about = new KAboutData(QStringLiteral("kcmaddressbookuserfeedbackconfig"),
-                                i18n("Configure User FeedBack"),
-                                QString(),
-                                QString(),
-                                KAboutLicense::GPL,
-                                i18n("(c), 2020-2021 Laurent Montel"));
-
-    about->addAuthor(i18n("Laurent Montel"), QString(), QStringLiteral("montel@kde.org"));
-
-    setAboutData(about);
     connect(mUserFeedbackWidget, &KUserFeedback::FeedbackConfigWidget::configurationChanged, this, &KCMKaddressbookUserFeedBackConfig::markAsChanged);
 
     lay->addWidget(mUserFeedbackWidget);
