@@ -8,6 +8,7 @@
 
 #include <KCModule>
 
+#include "kcmutils_version.h"
 #include <QVariant>
 namespace KUserFeedback
 {
@@ -20,7 +21,11 @@ class KCMKaddressbookUserFeedBackConfig : public KCModule
 {
     Q_OBJECT
 public:
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     explicit KCMKaddressbookUserFeedBackConfig(QWidget *parent, const QVariantList &args);
+#else
+    explicit KCMKaddressbookUserFeedBackConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
+#endif
     void load() override;
     void save() override;
     void defaults() override;
