@@ -32,7 +32,7 @@ ContactInfoProxyModel::ContactInfoProxyModel(QObject *parent)
 QVariant ContactInfoProxyModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
-        return QVariant();
+        return {};
         qCWarning(KADDRESSBOOK_LOG) << "invalid index!";
     }
     if (role >= Roles::PictureRole && role <= Roles::DescriptionRole) {
@@ -62,7 +62,7 @@ QVariant ContactInfoProxyModel::data(const QModelIndex &index, int role) const
             }
             switch (role) {
             case Roles::PictureRole:
-                return QVariant();
+                return {};
             case Roles::InitialsRole:
                 return mPendingGroupItems.contains(item.id()) ? i18n("...") : getInitials(item.id(), groupContacts);
             case Roles::DescriptionRole:
@@ -372,12 +372,7 @@ bool ContactInfoProxyModel::ContactCacheData::setData(const Akonadi::Item &item)
 
 bool ContactInfoProxyModel::ContactCacheData::validateItem(const Akonadi::Item &item) const
 {
-    bool result(true);
-    result |= item.isValid();
-    result |= mUid == QString::number(item.id());
-    result |= mGid == item.gid();
-    result |= item.hasPayload<KContacts::Addressee>();
-    return result;
+    return item.isValid() && mUid == QString::number(item.id()) && mGid == item.gid() && item.hasPayload<KContacts::Addressee>();
 }
 
 bool operator==(const ContactInfoProxyModel::ContactCacheData &lhs, const ContactInfoProxyModel::ContactCacheData &rhs)
