@@ -53,7 +53,6 @@
 #include <PimCommonAkonadi/ManageServerSideSubscriptionJob>
 #include <QPointer>
 
-#include <Akonadi/ContactDefaultActions>
 #include <Akonadi/ContactGroupEditorDialog>
 #include <Akonadi/ContactGroupViewer>
 #include <Akonadi/ContactViewer>
@@ -82,6 +81,7 @@
 #include <KWindowStateSaver>
 #include <QActionGroup>
 #include <QDBusConnection>
+#include <QDesktopServices>
 #include <QHBoxLayout>
 #include <QHeaderView>
 #include <QPrintDialog>
@@ -253,7 +253,7 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     mItemView->setRootIsDecorated(false);
     mItemView->header()->setDefaultAlignment(Qt::AlignCenter);
 
-    mActionManager = new Akonadi::StandardContactActionManager(guiClient->actionCollection(), this);
+    mActionManager = new ContactEditor::StandardContactActionManager(guiClient->actionCollection(), this);
     mActionManager->setCollectionSelectionModel(mCollectionView->selectionModel());
     mActionManager->setItemSelectionModel(mItemView->selectionModel());
 
@@ -270,11 +270,11 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
         mActionManager->createAction(standardAction);
     }
     guiClient->actionCollection()->setDefaultShortcut(mActionManager->action(Akonadi::StandardActionManager::DeleteItems), QKeySequence(Qt::Key_Delete));
-    QList<Akonadi::StandardContactActionManager::Type> contactActions;
-    contactActions << Akonadi::StandardContactActionManager::CreateContact << Akonadi::StandardContactActionManager::CreateContactGroup
-                   << Akonadi::StandardContactActionManager::EditItem;
+    QList<ContactEditor::StandardContactActionManager::Type> contactActions;
+    contactActions << ContactEditor::StandardContactActionManager::CreateContact << ContactEditor::StandardContactActionManager::CreateContactGroup
+                   << ContactEditor::StandardContactActionManager::EditItem;
 
-    for (Akonadi::StandardContactActionManager::Type contactAction : std::as_const(contactActions)) {
+    for (ContactEditor::StandardContactActionManager::Type contactAction : std::as_const(contactActions)) {
         mActionManager->createAction(contactAction);
     }
 
@@ -287,7 +287,7 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     connect(mItemView, qOverload<const Akonadi::Item &>(&Akonadi::EntityTreeView::currentChanged), this, &MainWidget::itemSelected);
     connect(mItemView,
             qOverload<const Akonadi::Item &>(&Akonadi::EntityTreeView::doubleClicked),
-            mActionManager->action(Akonadi::StandardContactActionManager::EditItem),
+            mActionManager->action(ContactEditor::StandardContactActionManager::EditItem),
             &QAction::trigger);
     connect(mItemView->selectionModel(), &QItemSelectionModel::currentChanged, this, &MainWidget::itemSelectionChanged);
 
@@ -564,11 +564,17 @@ void MainWidget::setupGui()
     detailsPaneLayout->addWidget(mDetailsViewStack);
 
     // the details widget for contacts
-    mContactDetails = new Akonadi::ContactViewer(mDetailsViewStack);
+    mContactDetails = new ContactEditor::ContactViewer(mDetailsViewStack);
+    connect(mContactDetails, &ContactEditor::ContactViewer::urlClicked, this, [](const QUrl &url) {
+        QDesktopServices::openUrl(url);
+    });
     mDetailsViewStack->addWidget(mContactDetails);
 
     // the details widget for contact groups
-    mContactGroupDetails = new Akonadi::ContactGroupViewer(mDetailsViewStack);
+    mContactGroupDetails = new ContactEditor::ContactGroupViewer(mDetailsViewStack);
+    connect(mContactGroupDetails, &ContactEditor::ContactGroupViewer::urlClicked, this, [](const QUrl &url) {
+        QDesktopServices::openUrl(url);
+    });
     mDetailsViewStack->addWidget(mContactGroupDetails);
 
     // the details widget for empty items
@@ -587,10 +593,6 @@ void MainWidget::setupGui()
     // the category filter widget which is embedded in the toolbar action
     mCategorySelectWidget = new CategorySelectWidget;
 
-    // setup the default actions
-    auto actions = new Akonadi::ContactDefaultActions(this);
-    actions->connectToView(mContactDetails);
-    actions->connectToView(mContactGroupDetails);
     mFormatter = new KAddressBookGrantlee::GrantleeContactFormatter;
     mFormatter->setApplicationDomain("kaddressbook");
 
@@ -625,17 +627,10 @@ void MainWidget::setupActions(KActionCollection *collection)
                                                             collection,
                                                             QStringLiteral("kaddressbook/viewertemplates/"),
                                                             this);
-    mGrantleeThemeManager->setDownloadNewStuffConfigFile(QStringLiteral(":/knsrc/data/kaddressbook_themes.knsrc"));
     connect(mGrantleeThemeManager, &GrantleeTheme::ThemeManager::grantleeThemeSelected, this, &MainWidget::slotGrantleeThemeSelected);
     connect(mGrantleeThemeManager, &GrantleeTheme::ThemeManager::updateThemes, this, &MainWidget::slotGrantleeThemesUpdated);
 
-    auto themeMenu = new KActionMenu(i18n("&Themes"), this);
-    collection->addAction(QStringLiteral("theme_menu"), themeMenu);
-
     initGrantleeThemeName();
-    auto group = new QActionGroup(this);
-    mGrantleeThemeManager->setThemeMenu(themeMenu);
-    mGrantleeThemeManager->setActionGroup(group);
 
     QAction *action = KStandardAction::print(this, &MainWidget::print, collection);
     action->setWhatsThis(i18nc("@info:whatsthis", "Print the complete address book or a selected number of contacts."));
@@ -765,12 +760,12 @@ void MainWidget::print()
 
 void MainWidget::newContact()
 {
-    mActionManager->action(Akonadi::StandardContactActionManager::CreateContact)->trigger();
+    mActionManager->action(ContactEditor::StandardContactActionManager::CreateContact)->trigger();
 }
 
 void MainWidget::newGroup()
 {
-    mActionManager->action(Akonadi::StandardContactActionManager::CreateContactGroup)->trigger();
+    mActionManager->action(ContactEditor::StandardContactActionManager::CreateContactGroup)->trigger();
 }
 
 /**
