@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -32,9 +32,7 @@ ManageShowCollectionProperties::ManageShowCollectionProperties(MainWidget *mainW
                            << QStringLiteral("PimCommon::CollectionAclPage") << QStringLiteral("Akonadi::CollectionMaintenancePage");
 }
 
-ManageShowCollectionProperties::~ManageShowCollectionProperties()
-{
-}
+ManageShowCollectionProperties::~ManageShowCollectionProperties() = default;
 
 void ManageShowCollectionProperties::showCollectionProperties()
 {
