@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,7 +23,7 @@ public:
 
     void setMainWidget(MainWidget *mainWidget);
 
-    bool initializeInterfaceRequires(PimCommon::AbstractGenericPluginInterface *interface) override;
+    bool initializeInterfaceRequires(PimCommon::AbstractGenericPluginInterface *abstractInterface) override;
     static KAddressBookPluginInterface *self();
 
 private:
