@@ -138,7 +138,7 @@ QString contactsToHtml(const KContacts::Addressee::List &contacts, const ColorSe
                 }
                 block.header += QLatin1Char(':');
 
-                block.entries = address.formattedAddress().split(QLatin1Char('\n'), Qt::KeepEmptyParts);
+                block.entries = address.formatted(KContacts::AddressFormatStyle::Postal).split(QLatin1Char('\n'), Qt::KeepEmptyParts);
                 blocks.append(block);
             }
         }
@@ -214,7 +214,7 @@ QString contactsToHtml(const KContacts::Addressee::List &contacts, const ColorSe
 class KABPrinting::AppearancePage : public QWidget, public Ui::AppearancePage_Base
 {
 public:
-    AppearancePage(QWidget *parent)
+    explicit AppearancePage(QWidget *parent)
         : QWidget(parent)
     {
         setupUi(this);
@@ -238,9 +238,7 @@ DetailledPrintStyle::DetailledPrintStyle(PrintingWizard *parent)
     mPageAppearance->kcbHeaderTextColor->setColor(config.readEntry(ContactHeaderForeColor, QColor(Qt::white)));
 }
 
-DetailledPrintStyle::~DetailledPrintStyle()
-{
-}
+DetailledPrintStyle::~DetailledPrintStyle() = default;
 
 void DetailledPrintStyle::print(const KContacts::Addressee::List &contacts, PrintProgress *progress)
 {
